==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1WebhookFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1WebhookFluent<A extends V1beta1WebhookFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildClientConfig instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1WebhookClientConfig getClientConfig();
    public V1beta1WebhookClientConfig buildClientConfig();
    public A withClientConfig(V1beta1WebhookClientConfig clientConfig);
    public Boolean hasClientConfig();
    public V1beta1WebhookFluent.ClientConfigNested<A> withNewClientConfig();
    public V1beta1WebhookFluent.ClientConfigNested<A> withNewClientConfigLike(V1beta1WebhookClientConfig item);
    public V1beta1WebhookFluent.ClientConfigNested<A> editClientConfig();
    public V1beta1WebhookFluent.ClientConfigNested<A> editOrNewClientConfig();
    public V1beta1WebhookFluent.ClientConfigNested<A> editOrNewClientConfigLike(V1beta1WebhookClientConfig item);
    public String getFailurePolicy();
    public A withFailurePolicy(String failurePolicy);
    public Boolean hasFailurePolicy();
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    
/**
 * This method has been deprecated, please use method buildNamespaceSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getNamespaceSelector();
    public V1LabelSelector buildNamespaceSelector();
    public A withNamespaceSelector(V1LabelSelector namespaceSelector);
    public Boolean hasNamespaceSelector();
    public V1beta1WebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
    public V1beta1WebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(V1LabelSelector item);
    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editNamespaceSelector();
    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(V1LabelSelector item);
    public A addToRules(int index,V1beta1RuleWithOperations item);
    public A setToRules(int index,V1beta1RuleWithOperations item);
    public A addToRules(V1beta1RuleWithOperations... items);
    public A addAllToRules(Collection<V1beta1RuleWithOperations> items);
    public A removeFromRules(V1beta1RuleWithOperations... items);
    public A removeAllFromRules(Collection<V1beta1RuleWithOperations> items);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1RuleWithOperations> getRules();
    public List<V1beta1RuleWithOperations> buildRules();
    public V1beta1RuleWithOperations buildRule(int index);
    public V1beta1RuleWithOperations buildFirstRule();
    public V1beta1RuleWithOperations buildLastRule();
    public V1beta1RuleWithOperations buildMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1RuleWithOperationsBuilder> predicate);
    public A withRules(List<V1beta1RuleWithOperations> rules);
    public A withRules(V1beta1RuleWithOperations... rules);
    public Boolean hasRules();
    public V1beta1WebhookFluent.RulesNested<A> addNewRule();
    public V1beta1WebhookFluent.RulesNested<A> addNewRuleLike(V1beta1RuleWithOperations item);
    public V1beta1WebhookFluent.RulesNested<A> setNewRuleLike(int index,V1beta1RuleWithOperations item);
    public V1beta1WebhookFluent.RulesNested<A> editRule(int index);
    public V1beta1WebhookFluent.RulesNested<A> editFirstRule();
    public V1beta1WebhookFluent.RulesNested<A> editLastRule();
    public V1beta1WebhookFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1RuleWithOperationsBuilder> predicate);

    public interface ClientConfigNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1WebhookClientConfigFluent<V1beta1WebhookFluent.ClientConfigNested<N>>{

        
    public N and();    public N endClientConfig();
}
    public interface NamespaceSelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V1beta1WebhookFluent.NamespaceSelectorNested<N>>{

        
    public N and();    public N endNamespaceSelector();
}
    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1RuleWithOperationsFluent<V1beta1WebhookFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}


}

==> client-java-api-4.0.0-sources.jar: io/kubernetes/client/models/V1beta1WebhookFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1beta1WebhookFluent<A extends V1beta1WebhookFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildClientConfig instead.
 * @return The buildable object.
 */
@Deprecated public V1beta1WebhookClientConfig getClientConfig();
    public V1beta1WebhookClientConfig buildClientConfig();
    public A withClientConfig(V1beta1WebhookClientConfig clientConfig);
    public Boolean hasClientConfig();
    public V1beta1WebhookFluent.ClientConfigNested<A> withNewClientConfig();
    public V1beta1WebhookFluent.ClientConfigNested<A> withNewClientConfigLike(V1beta1WebhookClientConfig item);
    public V1beta1WebhookFluent.ClientConfigNested<A> editClientConfig();
    public V1beta1WebhookFluent.ClientConfigNested<A> editOrNewClientConfig();
    public V1beta1WebhookFluent.ClientConfigNested<A> editOrNewClientConfigLike(V1beta1WebhookClientConfig item);
    public String getFailurePolicy();
    public A withFailurePolicy(String failurePolicy);
    public Boolean hasFailurePolicy();
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    
/**
 * This method has been deprecated, please use method buildNamespaceSelector instead.
 * @return The buildable object.
 */
@Deprecated public V1LabelSelector getNamespaceSelector();
    public V1LabelSelector buildNamespaceSelector();
    public A withNamespaceSelector(V1LabelSelector namespaceSelector);
    public Boolean hasNamespaceSelector();
    public V1beta1WebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
    public V1beta1WebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(V1LabelSelector item);
    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editNamespaceSelector();
    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
    public V1beta1WebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(V1LabelSelector item);
    public A addToRules(int index,V1beta1RuleWithOperations item);
    public A setToRules(int index,V1beta1RuleWithOperations item);
    public A addToRules(V1beta1RuleWithOperations... items);
    public A addAllToRules(Collection<V1beta1RuleWithOperations> items);
    public A removeFromRules(V1beta1RuleWithOperations... items);
    public A removeAllFromRules(Collection<V1beta1RuleWithOperations> items);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<V1beta1RuleWithOperations> getRules();
    public List<V1beta1RuleWithOperations> buildRules();
    public V1beta1RuleWithOperations buildRule(int index);
    public V1beta1RuleWithOperations buildFirstRule();
    public V1beta1RuleWithOperations buildLastRule();
    public V1beta1RuleWithOperations buildMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1RuleWithOperationsBuilder> predicate);
    public A withRules(List<V1beta1RuleWithOperations> rules);
    public A withRules(V1beta1RuleWithOperations... rules);
    public Boolean hasRules();
    public V1beta1WebhookFluent.RulesNested<A> addNewRule();
    public V1beta1WebhookFluent.RulesNested<A> addNewRuleLike(V1beta1RuleWithOperations item);
    public V1beta1WebhookFluent.RulesNested<A> setNewRuleLike(int index,V1beta1RuleWithOperations item);
    public V1beta1WebhookFluent.RulesNested<A> editRule(int index);
    public V1beta1WebhookFluent.RulesNested<A> editFirstRule();
    public V1beta1WebhookFluent.RulesNested<A> editLastRule();
    public V1beta1WebhookFluent.RulesNested<A> editMatchingRule(io.kubernetes.client.fluent.Predicate<V1beta1RuleWithOperationsBuilder> predicate);
    public String getSideEffects();
    public A withSideEffects(String sideEffects);
    public Boolean hasSideEffects();

    public interface ClientConfigNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1WebhookClientConfigFluent<V1beta1WebhookFluent.ClientConfigNested<N>>{

        
    public N and();    public N endClientConfig();
}
    public interface NamespaceSelectorNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1LabelSelectorFluent<V1beta1WebhookFluent.NamespaceSelectorNested<N>>{

        
    public N and();    public N endNamespaceSelector();
}
    public interface RulesNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1beta1RuleWithOperationsFluent<V1beta1WebhookFluent.RulesNested<N>>{

        
    public N and();    public N endRule();
}


}
